Rename DT_MIPS_RLD_MAP2 flag to DT_MIPS_RLD_MAP_REL

Change-Id: I2c0972f5ce3586c3f4f130034f7063f97557ab4e
diff --git a/linker/linker.cpp b/linker/linker.cpp
index 855b32b..93fab8f 100644
--- a/linker/linker.cpp
+++ b/linker/linker.cpp
@@ -3634,8 +3634,8 @@
           *dp = &_r_debug;
         }
         break;
-      case DT_MIPS_RLD_MAP2:
-        // Set the DT_MIPS_RLD_MAP2 entry to the address of _r_debug for GDB.
+      case DT_MIPS_RLD_MAP_REL:
+        // Set the DT_MIPS_RLD_MAP_REL entry to the address of _r_debug for GDB.
         {
           r_debug** dp = reinterpret_cast<r_debug**>(
               reinterpret_cast<ElfW(Addr)>(d) + d->d_un.d_val);